/*
 *  Kylin security execute control
 *
 *  This file contains status relate apis for Kylin
 *  security exectl
 *
 *  Authors:  songchuanfei <songchuanfei@kylinos.cn>
 *  Authors:  huanfuxi <huanfuxi@kylinos.cn>
 *  Authors:  mengyuan <mengyuan@kylinos.cn>
 *
 *  Copyright (C) 2017,Tianjin KYLIN Information Technology Co., Ltd.
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2 of the License, or (at your option) any later version.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the
 *  Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
 *  Boston, MA 02110-1301, USA.
 */
#ifndef _KYSEC_STATUS_H_
#define _KYSEC_STATUS_H_

#define SECURITYFS_MNT				"/sys/kernel/security"
#define KYSEC_STATUS_PATH SECURITYFS_MNT	"/kysec/status"
#define KYSEC_FUNC_DIR SECURITYFS_MNT		"/kysec/"

#define KYSEC_VERSION_PATH SECURITYFS_MNT	"/kysec/version"

/* func status */
enum {
	FUNC_DISABLED = 0,	//disabled
	FUNC_ENABLED,		//enabled
};

enum {
	FUNC_CTL_DENIED = 1,	// denied
	FUNC_CTL_WARNING,	// warning
	FUNC_CTL_PERMIT		// just disable user privacy data if func is kid
};

enum {
	NETCTL_STATUS_PERMIT = 3
};

/* func ids */
enum {
	FUNC_EXECTL = 0,	// execute control
	FUNC_NETCTL,		// network control
	FUNC_FPRO,		// file protection
	FUNC_KMOD,		// kernel module protection
	FUNC_3ADM,		// 3 admin
	FUNC_PPRO,		// process protection
	FUNC_DEVCTL,		// device control
	FUNC_IPT,		// iptables status
	FUNC_TBOOT,
	FUNC_SM,
	FUNC_KID,
	FUNC_PBLK,              // program blacklist
	FUNC_EPERM,
	FUNC_MAX
};

#define KYSEC_STATUS_DISABLED	0
#define KYSEC_STATUS_ENABLED	2
#define KYSEC_STATUS_SOFTMODE	4

static const char * const func_status_strs[] = {
	"kysec_exectl",
	"kysec_netctl",
	"kysec_fpro",
	"kysec_kmodpro",
	"kysec_3adm",
	"kysec_ppro",
	"kysec_devctl",
	"kysec_ipt",
	"kysec_tboot",
	"kysec_sm",
	"kysec_kid",
	"kysec_pblk",
	"kysec_eperm",
};

/* version ids */
enum {
	KYSEC_MAIN_VER = 0,	// 主版本号
	KYSEC_EXECTL_VER,	// 执行控制版本号
	KYSEC_NETCTL_VER,	// 网络管控版本号
	KYSEC_FPRO_VER,		// 文件保护版本号
	KYSEC_KMOD_VER,		// 内核模块保护版本号
	KYSEC_3ADM_VER,		// 三权分立版本号
	KYSEC_PPRO_VER,		// 进程保护版本号
	KYSEC_DEVCTL_VER,	// 设备管控版本号
	KYSEC_PBLK_VER,         // 程序黑名单版本号
	KYSEC_MAX_VER
};

#ifdef __cplusplus
extern "C" {
#endif

extern int kysec_getstatus(void);

extern int kysec_get_func_status(int func_id);

#define kysec_get_3adm_status()	kysec_get_func_status(FUNC_3ADM)

extern int kysec_version_get(int ver_id, char **version);

extern int kysec_check_kid_support(void);

extern int kysec_check_readonly_ppro_support(void);

extern int kysec_kid_privilege_is_support_uid(void);

#ifdef __cplusplus
}
#endif

#endif
